import { useTransactions } from "@/contexts/TransactionContext";
import { formatCurrency } from "@/utils/format";

export default function BalanceSummary() {
  const { currentBalance, transactions } = useTransactions();

  // Calculate totals
  const totals = transactions.reduce(
    (acc, transaction) => {
      // Add service charges from ALL transaction types
      acc.charges += transaction.serviceCharge;
      
      if (transaction.type === "receive") {
        acc.received += transaction.amount;
      } else if (transaction.type === "send") {
        acc.sent += transaction.amount;
      } else if (transaction.type === "load-wallet") {
        // For load-wallet, add it to the "sent" category since it's a deduction
        acc.sent += transaction.amount;
      }
      return acc;
    },
    { received: 0, sent: 0, charges: 0 }
  );

  return (
    <div className="bg-white rounded-lg shadow p-6">
      <h2 className="text-lg font-semibold text-gray-800 mb-4">Account Balance</h2>
      <div className="flex items-baseline space-x-2">
        <span className="text-3xl font-bold text-gray-900">{formatCurrency(currentBalance)}</span>
        <span className="text-sm text-gray-500">PHP</span>
      </div>

      <div className="mt-4 grid grid-cols-3 gap-2 text-center text-sm">
        <div className="bg-green-50 rounded p-2">
          <div className="font-medium text-success">Received</div>
          <div className="font-semibold">{formatCurrency(totals.received)}</div>
        </div>
        <div className="bg-red-50 rounded p-2">
          <div className="font-medium text-error">Sent</div>
          <div className="font-semibold">{formatCurrency(totals.sent)}</div>
        </div>
        <div className="bg-yellow-50 rounded p-2">
          <div className="font-medium text-warning">Charges</div>
          <div className="font-semibold">{formatCurrency(totals.charges)}</div>
        </div>
      </div>
    </div>
  );
}
