import { useState } from "react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { useTransactions } from "@/contexts/TransactionContext";

export default function TransactionFilter() {
  const { setDateFilter, clearDateFilter } = useTransactions();
  const [date, setDate] = useState<string>(new Date().toISOString().split("T")[0]);

  const handleApplyFilter = () => {
    setDateFilter(date);
  };

  const handleClearFilter = () => {
    setDate("");
    clearDateFilter();
  };

  return (
    <div className="bg-white rounded-lg shadow p-6 mb-6">
      <h2 className="text-lg font-semibold text-gray-800 mb-4">Transaction History</h2>
      <div className="flex flex-wrap items-center gap-4">
        <div className="flex-grow">
          <Label htmlFor="filter-date" className="block text-sm font-medium text-gray-700 mb-1">
            Filter by Date
          </Label>
          <Input
            id="filter-date"
            type="date"
            value={date}
            onChange={(e) => setDate(e.target.value)}
          />
        </div>
        <div className="flex mt-6 space-x-2">
          <Button onClick={handleApplyFilter}>
            Apply Filter
          </Button>
          <Button
            variant="outline"
            onClick={handleClearFilter}
          >
            Clear
          </Button>
        </div>
      </div>
    </div>
  );
}
