import { Button } from "@/components/ui/button";
import { ChevronLeftIcon, ChevronRightIcon } from "lucide-react";

interface TransactionPaginationProps {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
}

export default function TransactionPagination({
  currentPage, 
  totalPages,
  onPageChange
}: TransactionPaginationProps) {
  if (totalPages <= 1) return null;

  return (
    <div className="flex items-center justify-between py-4">
      <Button
        variant="outline"
        size="sm"
        onClick={() => onPageChange(currentPage - 1)}
        disabled={currentPage === 1}
      >
        <ChevronLeftIcon className="h-4 w-4 mr-2" />
        Previous
      </Button>
      
      <div className="flex items-center gap-1 text-sm">
        <span className="font-medium">{currentPage}</span>
        <span>/</span>
        <span>{totalPages}</span>
      </div>
      
      <Button
        variant="outline"
        size="sm"
        onClick={() => onPageChange(currentPage + 1)}
        disabled={currentPage === totalPages}
      >
        Next
        <ChevronRightIcon className="h-4 w-4 ml-2" />
      </Button>
    </div>
  );
}